summaryrefslogtreecommitdiff
path: root/validation/test
diff options
context:
space:
mode:
authorJean-Philippe NOEL2012-09-26 17:27:39 +0200
committerJean-Philippe NOEL2012-10-05 09:46:07 +0200
commit9ae2acfb608504ef99f3b6d51a0f05e2bdfd95e2 (patch)
tree06715ba1824d953b4810f75ea2e26f8b6dd5ff8c /validation/test
parentd722b5ecb56f3a4e28b0db91a640eaa858c1a3cc (diff)
validation: shorten the names of the P2P throughput files, refs #3363
Diffstat (limited to 'validation/test')
-rw-r--r--validation/test/P2P_throughput/P2P_throughput.dia (renamed from validation/test/P2P_throughput_report/P2P_throughput_report.dia)bin5291 -> 5291 bytes
-rw-r--r--validation/test/P2P_throughput/P2P_throughput.py (renamed from validation/test/P2P_throughput_report/P2P_throughput_report.py)24
-rw-r--r--validation/test/P2P_throughput/P2P_throughput.rst (renamed from validation/test/P2P_throughput_report/P2P_throughput_report.rst)0
-rw-r--r--validation/test/P2P_throughput/P2P_throughput_caller.py (renamed from validation/test/P2P_throughput_report/P2P_throughput_report_caller.py)17
-rw-r--r--validation/test/P2P_throughput/config.py (renamed from validation/test/P2P_throughput_report/config.py)3
5 files changed, 22 insertions, 22 deletions
diff --git a/validation/test/P2P_throughput_report/P2P_throughput_report.dia b/validation/test/P2P_throughput/P2P_throughput.dia
index 832e5e7c84..832e5e7c84 100644
--- a/validation/test/P2P_throughput_report/P2P_throughput_report.dia
+++ b/validation/test/P2P_throughput/P2P_throughput.dia
Binary files differ
diff --git a/validation/test/P2P_throughput_report/P2P_throughput_report.py b/validation/test/P2P_throughput/P2P_throughput.py
index 5454abfb81..181cefc741 100644
--- a/validation/test/P2P_throughput_report/P2P_throughput_report.py
+++ b/validation/test/P2P_throughput/P2P_throughput.py
@@ -686,29 +686,29 @@ if __name__ == "__main__":
"sjr_offset_db":-14} == \
get_waveform_data(-63, (1, 38), (0, 50), 17, 0, 10, 10)
- assert "./P2P_throughput_report_UDP_frame_size_(5, 5)bytes" == \
+ assert "./P2P_throughput_UDP_frame_size_(5, 5)bytes" == \
get_file_prefix("UDP", "frame_size", None, (5, 5), "bytes", None, ".")
- assert "./P2P_throughput_report_UDP_SNR_-5dB" == \
+ assert "./P2P_throughput_UDP_SNR_-5dB" == \
get_file_prefix("UDP", "SNR", None, -5, "dB", None, ".")
- assert "/reports/P2P_throughput_report_UDP_SNR_-5dB" == \
+ assert "/reports/P2P_throughput_UDP_SNR_-5dB" == \
get_file_prefix("UDP", "SNR", None, -5, "dB", None, "/reports")
- assert "reports/P2P_throughput_report_UDP_SNR_-5dB" == \
+ assert "reports/P2P_throughput_UDP_SNR_-5dB" == \
get_file_prefix("UDP", "SNR", None, -5, "dB", None, "reports")
- assert "reports/P2P_throughput_report_UDP_SNR_-5dB" == \
+ assert "reports/P2P_throughput_UDP_SNR_-5dB" == \
get_file_prefix("UDP", "SNR", None, -5, "dB", None, "reports/")
- assert "reports/subreports/P2P_throughput_report_UDP_SNR_-5dB" == \
+ assert "reports/subreports/P2P_throughput_UDP_SNR_-5dB" == \
get_file_prefix("UDP", "SNR", None, -5, "dB", None, "reports/subreports")
- assert "reports/subreports/P2P_throughput_report_UDP_SJR_15_-5dB" == \
+ assert "reports/subreports/P2P_throughput_UDP_SJR_15_-5dB" == \
get_file_prefix("UDP", "SJR", (15,), -5, "dB", None, "reports/subreports")
- assert "reports/P2P_throughput_report_TCP_SNR" == \
+ assert "reports/P2P_throughput_TCP_SNR" == \
get_file_prefix("TCP", "SNR", None, None, None, None, "reports")
- assert "reports/P2P_throughput_report_TCP" == \
+ assert "reports/P2P_throughput_TCP" == \
get_file_prefix("TCP", None, None, None, None, None, "reports")
- assert "reports/P2P_throughput_report" == \
+ assert "reports/P2P_throughput" == \
get_file_prefix(None, None, None, None, None, None, "reports")
- assert "P2P_throughput_report" == \
+ assert "P2P_throughput" == \
get_file_prefix(None, None, None, None, None, None, "")
- assert "reports/P2P_throughput_report_UDP_SNR_-10dB_Throughput" == \
+ assert "reports/P2P_throughput_UDP_SNR_-10dB_Throughput" == \
get_file_prefix("UDP", "SNR", None, -10, "dB", "Throughput", "reports")
assert flatten([]) == []
diff --git a/validation/test/P2P_throughput_report/P2P_throughput_report.rst b/validation/test/P2P_throughput/P2P_throughput.rst
index e65af34570..e65af34570 100644
--- a/validation/test/P2P_throughput_report/P2P_throughput_report.rst
+++ b/validation/test/P2P_throughput/P2P_throughput.rst
diff --git a/validation/test/P2P_throughput_report/config.py b/validation/test/P2P_throughput/config.py
index a26512c926..fbe65c7757 100644
--- a/validation/test/P2P_throughput_report/config.py
+++ b/validation/test/P2P_throughput/config.py
@@ -13,7 +13,8 @@
"get_CE_stats":True,
#CE stats which difference, before and after each serie of measurements,
#is displayed in the report
- "displayed_CE_stats": ["Restart BER",
+ "displayed_CE_stats": ["BLE",
+ "Restart BER",
"Restart PB error rate",
"Restart peer request",
"Restart tone map update",
diff --git a/validation/test/P2P_throughput_report/P2P_throughput_report_caller.py b/validation/test/P2P_throughput/P2P_throughput_caller.py
index 5b132d0e0a..fc61423a5c 100644
--- a/validation/test/P2P_throughput_report/P2P_throughput_report_caller.py
+++ b/validation/test/P2P_throughput/P2P_throughput_caller.py
@@ -1,16 +1,15 @@
# -*- coding: utf-8 -*-
-"""Module allowing to call P2P_throughput_report, with the adequate
-configuration"""
+"""Module allowing to call P2P_throughput, with the adequate configuration"""
import numpy
-import P2P_throughput_report
+import P2P_throughput
import sys
import os
-class P2P_throughput_report_caller:
+class P2P_throughput_caller:
- """P2P throughput report caller"""
+ """P2P throughput caller"""
def __init__(self):
from optparse import OptionParser
@@ -80,13 +79,13 @@ class P2P_throughput_report_caller:
self._commands[cmd](config)
def run_report(self, config):
- P2P_throughput_report.report(config)
+ P2P_throughput.report(config)
def run_set_tokens(self, config):
- P2P_throughput_report.set_tokens(config)
+ P2P_throughput.set_tokens(config)
def run_clear_tokens(self, config):
- P2P_throughput_report.clear_tokens(config)
+ P2P_throughput.clear_tokens(config)
def evaluate(file_name):
config_file = open(file_name, "r")
@@ -97,7 +96,7 @@ def evaluate(file_name):
if __name__ == "__main__":
try:
- P2P_throughput_report_caller().run(sys.argv[1:])
+ P2P_throughput_caller().run(sys.argv[1:])
except RuntimeError, e:
print >> sys.stderr, "Error:", e
sys.exit(1)